@@ -35,7 +35,7 @@ class CJMonitorFilter(DeviceFilter):
 
     def __init__(self, company_id=CJ_MANUFACTURER_ID, beacon_type=CJ_TEMPHUM_TYPE):
         """Initialize filter."""
-        super(CJMonitorFilter, self).__init__()
+        super().__init__()
         if company_id is None and beacon_type is None:
             raise ValueError("CJMonitorFilter needs at least one argument set")
         if company_id is not None:
@@ -48,7 +48,7 @@ class IBeaconFilter(DeviceFilter):
 
     def __init__(self, uuid=None, major=None, minor=None):
         """Initialize filter."""
-        super(IBeaconFilter, self).__init__()
+        super().__init__()
         if uuid is None and major is None and minor is None:
             raise ValueError("IBeaconFilter needs at least one argument set")
         if uuid is not None:
@@ -64,7 +64,7 @@ class EddystoneFilter(DeviceFilter):
 
     def __init__(self, namespace=None, instance=None):
         """Initialize filter."""
-        super(EddystoneFilter, self).__init__()
+        super().__init__()
         if namespace is None and instance is None:
             raise ValueError("EddystoneFilter needs at least one argument set")
         if namespace is not None:
@@ -78,7 +78,7 @@ class EstimoteFilter(DeviceFilter):
 
     def __init__(self, identifier=None, protocol_version=None):
         """Initialize filter."""
-        super(EstimoteFilter, self).__init__()
+        super().__init__()
         if identifier is None and protocol_version is None:
             raise ValueError("EstimoteFilter needs at least one argument set")
         if identifier is not None:
@@ -92,7 +92,7 @@ class ExposureNotificationFilter(DeviceFilter):
 
     def __init__(self, identifier):
         """Initialize filter."""
-        super(ExposureNotificationFilter, self).__init__()
+        super().__init__()
         if identifier is None:
             raise ValueError("ExposureNotificationFilter needs identifier to be set")
         self.properties['identifier'] = identifier
@@ -103,11 +103,11 @@ class BtAddrFilter(DeviceFilter):
 
     def __init__(self, bt_addr):
         """Initialize filter."""
-        super(BtAddrFilter, self).__init__()
+        super().__init__()
         try:
             bt_addr = bt_addr.lower()
-        except AttributeError:
-            raise ValueError("bt_addr({}) wasn't a string".format(bt_addr))
+        except AttributeError as exc:
+            raise ValueError("bt_addr({}) wasn't a string".format(bt_addr)) from exc
         if not is_valid_mac(bt_addr):
             raise ValueError("Invalid bluetooth MAC address given,"
                              " format should match aa:bb:cc:dd:ee:ff")
